@@ -182,7 +182,7 @@ class Model:
             print(f"Running on compute device: {self.compute_device}")
             print(f"Model size: {count_parameters(self.model)} parameters\n")
 
-    def load_data(self, data, batch_size=2 ** 9, train=False, verbose=True):
+    def load_data(self, data, batch_size=2 ** 9, train=False):
         self.batch_size = batch_size
         inference = not train
         data_loaders = EDM_CsvLoader(
@@ -193,7 +193,7 @@ class Model:
             verbose=self.verbose,
             elem_prop=self.elem_prop,
         )
-        if verbose:
+        if self.verbose:
             print(
                 f"loading data with up to {data_loaders.n_elements:0.0f} "
                 f"elements in the formula"
@@ -213,7 +213,7 @@ class Model:
             self.train_loader = data_loader
         self.data_loader = data_loader
 
-    def train(self, verbose=True):
+    def train(self):
         self.model.train()
         ti = time()
         minima = []
@@ -249,16 +249,14 @@ class Model:
             epoch_check = (self.epoch + 1) % (2 * self.epochs_step) == 0
             learning_time = epoch_check and self.epoch >= swa_check
             if learning_time:
-                act_v, pred_v, _, _ = self.predict(
-                    loader=self.data_loader, verbose=verbose
-                )
+                act_v, pred_v, _, _ = self.predict(loader=self.data_loader)
                 mae_v = mean_absolute_error(act_v, pred_v)
                 self.optimizer.update_swa(mae_v)
                 minima.append(self.optimizer.minimum_found)
 
         if learning_time and not any(minima):
             self.optimizer.discard_count += 1
-            if verbose:
+            if self.verbose:
                 print(f"Epoch {self.epoch} failed to improve.")
                 print(
                     f"Discarded: {self.optimizer.discard_count}/"
@@ -287,7 +285,6 @@ class Model:
         k=6,
         base_lr=1e-4,
         max_lr=6e-3,
-        verbose=True,
     ):
         assert_train_str = "Please Load Training Data (self.train_loader)"
         assert_val_str = "Please Load Validation Data (self.data_loader)"
@@ -299,7 +296,7 @@ class Model:
 
         self.epochs_step = epochs_step
         self.step_size = self.epochs_step * len(self.train_loader)
-        if verbose:
+        if self.verbose:
             print(
                 f"stepping every {self.step_size} training passes,",
                 f"cycling lr every {self.epochs_step} epochs",
@@ -307,19 +304,19 @@ class Model:
         if epochs is None:
             n_iterations = 1e4
             epochs = int(n_iterations / len(self.data_loader))
-            if verbose:
+            if self.verbose:
                 print(f"running for {epochs} epochs")
         if checkin is None:
             # TODO: not sure if epochs_step has to be 10 (and epochs=40) for this to
             # work (check with Anthony)
             checkin = self.epochs_step * 2
-            if verbose:
+            if self.verbose:
                 print(
                     f"checkin at {self.epochs_step*2} " f"epochs to match lr scheduler"
                 )
         if epochs % (self.epochs_step * 2) != 0:
             updated_epochs = epochs - epochs % (self.epochs_step * 2)
-            if verbose:
+            if self.verbose:
                 print(
                     f"epochs not divisible by {self.epochs_step * 2}, "
                     f"updating epochs to {updated_epochs} for learning"
@@ -329,7 +326,7 @@ class Model:
         self.step_count = 0
         if criterion is None:
             if self.classification:
-                if verbose:
+                if self.verbose:
                     print("Using BCE loss for classification task")
                 self.criterion = BCEWithLogitsLoss
             else:
@@ -368,24 +365,20 @@ class Model:
             self.epoch = epoch
             self.epochs = epochs
             ti = time()
-            self.train(verbose=verbose)
+            self.train()
             # print(f'epoch time: {(time() - ti):0.3f}')
             self.lr_list.append(self.optimizer.param_groups[0]["lr"])
 
             if (epoch + 1) % checkin == 0 or epoch == epochs - 1 or epoch == 0:
                 ti = time()
-                act_t, pred_t, _, _ = self.predict(
-                    loader=self.train_loader, verbose=verbose
-                )
+                act_t, pred_t, _, _ = self.predict(loader=self.train_loader)
                 dt = time() - ti
                 datasize = len(act_t)
                 # print(f'inference speed: {datasize/dt:0.3f}')
                 # PARAMETER: mae vs. rmse?
                 mae_t = mean_absolute_error(act_t, pred_t)
                 self.loss_curve["train"].append(mae_t)
-                act_v, pred_v, _, _ = self.predict(
-                    loader=self.data_loader, verbose=verbose
-                )
+                act_v, pred_v, _, _ = self.predict(loader=self.data_loader)
                 mae_v = mean_absolute_error(act_v, pred_v)
                 self.loss_curve["val"].append(mae_v)
                 epoch_str = f"Epoch: {epoch}/{epochs} ---"
@@ -396,7 +389,7 @@ class Model:
                     val_auc = roc_auc_score(act_v, pred_v)
                     train_str = f"train auc: {train_auc:0.3f}"
                     val_str = f"val auc: {val_auc:0.3f}"
-                if verbose:
+                if self.verbose:
                     print(epoch_str, train_str, val_str)
 
                 if self.epoch >= (self.epochs_step * self.swa_start - 1):
@@ -468,7 +461,7 @@ class Model:
                     plt.show()
 
             if self.optimizer.discard_count >= self.discard_n:
-                if verbose:
+                if self.verbose:
                     print(
                         f"Discarded: {self.optimizer.discard_count}/"
                         f"{self.discard_n} weight updates, "
@@ -480,11 +473,11 @@ class Model:
         if not (self.optimizer.discard_count >= self.discard_n):
             self.optimizer.swap_swa_sgd()
 
-    def predict(self, data=None, loader=None, verbose=True):
+    def predict(self, data=None, loader=None):
         if data is None and loader is None:
             raise SyntaxError("Specify either data *or* loader, not neither.")
         elif data is not None and loader is None:
-            self.load_data(data, verbose=verbose)
+            self.load_data(data)
             loader = self.data_loader
         elif data is not None and loader is not None:
             raise SyntaxError("Specify either data *or* loader, not both.")
@@ -524,16 +517,16 @@ class Model:
 
         return (act, pred, formulae, uncert)
 
-    def save_network(self, model_name=None, verbose=True):
+    def save_network(self, model_name=None):
         if model_name is None:
             model_name = self.model_name
             os.makedirs("models/trained_models", exist_ok=True)
             path = f"models/trained_models/{model_name}.pth"
-            if verbose:
+            if self.verbose:
                 print(f"Saving network ({model_name}) to {path}")
         else:
             path = f"models/trained_models/{model_name}.pth"
-            if verbose:
+            if self.verbose:
                 print(f"Saving checkpoint ({model_name}) to {path}")
 
         self.network = {
